import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.*;

public class GenDistinctSmallPrimes {

    public final static int SEED = "halfway-there".hashCode();
    public final static Random rng = new Random(SEED);
    public final static int ARGS_COUNT = 3;
    
    public static void main(String[] args) {
        if (args.length < ARGS_COUNT) {
            throw new IllegalArgumentException(
                    String.format("Expected %d arguments, but got %d instead", ARGS_COUNT, args.length));
        }
        rng.setSeed(Arrays.hashCode(args));
        int tests = Integer.parseInt(args[0]);
        long limit = Long.parseLong(args[1]);
        int maxPrime = Integer.parseInt(args[2]);
        generateRandom(tests, limit, maxPrime);
    }

    static void generateRandom(int t, long limit, int maxPrime) {
        List<Integer> primeList =  new ArrayList<>();
        for (int i = 2; i <= maxPrime; i++) {
            boolean prime = true;
            for (int j = 2; j * j <= i; j++) {
                prime &= i % j != 0;
            }
            if (prime) {
                primeList.add(i);
            }
        }
        try (PrintWriter out = new PrintWriter(System.out)) {
            out.println(t);
            for (int i = 0; i < t; i++) {
                long cur = 1;
                Set<Integer> usedPrimes = new HashSet<>();
                while (true) {
                    int pr = primeList.get(rng.nextInt(primeList.size()));
                    if (usedPrimes.contains(pr)) {
                        continue;
                    }
                    if (cur * 1.0 * pr < limit) {
                        cur *= pr;
                        usedPrimes.add(pr);
                    } else {
                        break;
                    }
                }
                out.println(cur);
            }
        }
    }
}
