import kotlin.math.*
import kotlin.random.*

data class Point(val x:Double, val y:Double) {
    operator fun minus(other: Point) = Point(x - other.x, y - other.y)
    operator fun plus(other: Point) = Point(x + other.x, y + other.y)
    operator fun times(other: Point) = x.toLong() * other.y - y.toLong() * other.x
}

const val EPS = 1e-7

val Double.sign get() = when {
    this < -EPS -> -1
    this < EPS -> 0
    else -> 1
}

data class Line(val a: Double, val b: Double, val c: Double) {
    fun moveTo(p: Point, r: Double) : Line {
        val d = -a * p.x - b * p.y
        return Line(a, b, (r * c + d) / (r + 1))
    }
    fun side(p: Point) = (a * p.x + b * p.y + c).sign
    fun parallel(other: Line) = (a * other.b - b - other.a).absoluteValue < EPS
    fun intersect(other: Line) : Point {
        val d = a * other.b - other.a * b
        return Point(
            -(c * other.b - other.c * b) / d,
            -(a * other.c - other.a * c) / d
        )
    }
}

fun Line(p1:Point, p2:Point) : Line {
    val a = p1.y - p2.y
    val b = p2.x - p1.x
    val d = sqrt(a*a+b*b)
    val an = a / d
    val bn = b / d
    return Line(an, bn, -an * p1.x - bn * p1.y)
}

fun main() {
    val n = readInt()
    val ps = List(n) {
        val (x, y) = readInts()
        Point(x.toDouble(), y.toDouble())
    }.let { it + it[0] }
    var pid = 0
    val lines = ps.zipWithNext().map {
        while ((it.second - it.first) * (ps[pid+1] - ps[pid]) >= 0) {
            pid = (pid + 1) % n
        }
        Line(it.first, it.second) to ps[pid]
    }
    var lf = 1.0
    var rg = 2.0
    fun check(ratio: Double) : Boolean {
        val ls = lines.map { it.first.moveTo(it.second, ratio) }
        var p : Point = ls[0].intersect(ls[1])
        val otherls = ls.take(2) + ls.drop(2).shuffled()
        for ((index, l) in otherls.withIndex()) {
            if (l.side(p) < 0) {
                var pp : Point? = null
                for (ol in otherls.asSequence().take(index).filterNot { l.parallel(it) }) {
                    if (pp == null || ol.side(pp) < 0) {
                        pp = l.intersect(ol)
                    }
                }
                if (pp == null || otherls.asSequence().take(index).any { it.side(pp) < 0 }) {
                    return false
                }
                p = pp
            }
        }
        return ls.all { it.side(p) >= 0 }.also { if (it) { System.err.println("$ratio $p") } }
    }
    repeat(30) {
        val mid = (lf + rg) / 2
        if (check(mid)) {
            rg = mid
        } else {
            lf = mid
        }
    }
    println(lf)
}

private fun readLn() = readLine()!!
private fun readInt() = readLn().toInt()
private fun readLongs() = readStrings().map { it.toLong() }
private fun readStrings() = readLn().split(" ")
private fun readInts() = readStrings().map { it.toInt() }