#include "testlib.h"

using namespace std;

struct vertex {
	int white;
	int black;
};

struct DSU {
	vector<int> p;

	DSU(int n) : p(n) {
		for (int i = 0; i < n; i++) {
			p[i] = i;
		}
	}

	int get(int v) {
		return v == p[v] ? v : (p[v] = get(p[v]));
	}

	bool join(int v, int u) {
		v = get(v);
		u = get(u);
		p[v] = u;
		return v != u;
	}
};

bool readAns(InStream &ouf, vector<vertex> const &a) {
	string word = ouf.readToken("Yes|No");
	if (word == "No") return false;
	int n = (int) a.size();
	DSU dsu(n);
	vector<int> white(n), black(n);
	for (int i = 0; i + 1 < n; i++) {
		int v = ouf.readInt(1, n) - 1;
		int u = ouf.readInt(1, n) - 1;
		string color = ouf.readToken("W|B");
		if (v == u) {
			ouf.quitf(_wa, "[n = %d]: not a tree, a loop (%d, %d) found in edge list", n, v + 1, u + 1);
		}
		if (!dsu.join(v, u)) {
			ouf.quitf(_wa, "[n = %d]: not a tree, %d -> %d existed before edge #%d", n, v + 1, u + 1, i + 1);
		}
		if (color == "W") {
			white[v]++;
			white[u]++;
		} else {
			black[v]++;
			black[u]++;
		}
	}
	for (int i = 0; i < n; i++) {
		if (white[i] != a[i].white || black[i] != a[i].black) {
			ouf.quitf(_wa, "[n = %d]: vertex %d expected (W = %d, B = %d), but found (W = %d, B = %d)", n, i + 1, a[i].white, a[i].black, white[i], black[i]);
		}
	}
	return true;
}

bool checkSingleTest() {
	int n = inf.readInt();
	vector<vertex> a(n);
	for (auto &e : a) {
		e.white = inf.readInt();
		e.black = inf.readInt();
	}
	bool pa = readAns(ouf, a);
	bool ja = readAns(ans, a);
	if (pa != ja) {
		if (ja) {
			quitf(_wa, "[n = %d]: Jury found solution, but participant didn't", n);
		} else {
			quitf(_fail, "[n = %d]: Jury didn't find any solution, but participant did", n);
		}
	}
	return pa;
}

int main(int argc, char **argv) {
	registerTestlibCmd(argc, argv);
	int t = inf.readInt();
	int countYes = 0;
	for (int ct = 0; ct < t; ct++) {
		setTestCase(ct + 1);
		countYes += checkSingleTest() ? 1 : 0;
	}
	quitf(_ok, "%d 'Yes' out of %d cases", countYes, t);
}
