#include <bits/stdc++.h>

/**
 * Author: Niyaz Nigmatullin
 */

using namespace std;

struct vertex {
	int white;
	int black;
	int id;
};


struct edge {
	int v;
	int u;
	int color;
};

struct answer {
	bool answerExists;
	vector<edge> ans;
};

int countWhiteComponents(vector<vertex> const &a) {
	int n = (int) a.size();
	long long sumWhite = 0;
	long long sumBlack = 0;
	int nonZeroWhites = 0;
	for (int i = 0; i < n; i++) {
		sumWhite += a[i].white;
		sumBlack += a[i].black;
		if (a[i].white == 0 && a[i].black == 0 && n > 1) {
			return -1;
		}
		if (a[i].white != 0) {
			nonZeroWhites++;
		}
	}
	if (sumWhite % 2 != 0 || sumBlack % 2 != 0 || sumWhite + sumBlack != 2 * (n - 1) || (nonZeroWhites > 0 && sumWhite > 2 * (nonZeroWhites - 1))) {
		return -1;
	}
	return (int) ((2 * n - sumWhite) / 2);
}

template<typename T>
T takeLast(vector<T> &a) {
	assert(!a.empty());
	T v = a.back();
	a.pop_back();
	return v;
}

answer solve(vector<vertex> const &a) {
	int n = (int) a.size();
	int whiteComponents = countWhiteComponents(a);
	if (whiteComponents < 0) {
		return {false, {}};
	}
	vector<edge> ans;
	vector<vector<int>> components;
	vector<int> componentId(n, -1);
	for (int i = 0; i < n; i++) {
		if (a[i].white == 0) {
			componentId[i] = (int) components.size();
			components.push_back({i});
		}
	}
	for (int i = 0; i < n && (int) components.size() < whiteComponents; i++) {
		if (componentId[i] >= 0 || (a[i].black == 0 && whiteComponents != 1)) continue;
		componentId[i] = (int) components.size();
		components.push_back({i});
	}
	if ((int) components.size() != whiteComponents) {
		return {false, {}};
	}
	{
		vector<int> leaves;
		vector<int> nonLeaves;
		for (auto &e : a) {
			if (componentId[e.id] >= 0) continue;
			(e.white == 1 ? leaves : nonLeaves).push_back(e.id);
		}
		auto giveLeaves = [&](int uId, int needLeaves) {
			int comp = componentId[uId];
			while (needLeaves > 0) {
				int v = takeLast(leaves);
				componentId[v] = comp;
				components[comp].push_back(v);
				ans.push_back({uId, v, 0});
				--needLeaves;
			}
		};
		for (int comp = 0; comp < whiteComponents; comp++) {
			auto &root = a[components[comp][0]];
			giveLeaves(root.id, root.white);
		}
		for (int uId : nonLeaves) {
			auto &u = a[uId];
			edge last = takeLast(ans);
			ans.push_back({last.v, uId, 0});
			ans.push_back({last.u, uId, 0});
			componentId[uId] = componentId[last.v];
			components[componentId[uId]].push_back(uId);
			giveLeaves(uId, u.white - 2);
		}
		assert(leaves.empty());
	}
	if (whiteComponents > 1) {
		vector<vector<int>> compToConnect(whiteComponents);
		vector<int> leaves;
		vector<int> nonLeaves;
		for (int i = 0; i < whiteComponents; i++) {
			for (int uId : components[i]) {
				auto &u = a[uId];
				for (int j = 0; j < u.black; j++) {
					compToConnect[i].push_back(uId);
				}
			}
			assert(!compToConnect[i].empty());
			(compToConnect[i].size() == 1 ? leaves : nonLeaves).push_back(i);
		}
		vector<edge> blackEdges;
		{
			int leaf1 = takeLast(leaves);
			int leaf2 = takeLast(leaves);
			blackEdges.push_back({leaf1, leaf2, 1});
		}
		for (int u : nonLeaves) {
			edge last = takeLast(blackEdges);
			blackEdges.push_back({u, last.v, 1});
			blackEdges.push_back({u, last.u, 1});
			int needLeaves = (int) compToConnect[u].size() - 2;
			for (int i = 0; i < needLeaves; i++) {
				blackEdges.push_back({u, takeLast(leaves), 1});
			}
		}
		assert(leaves.empty());
		for (edge &e : blackEdges) {
			int v = takeLast(compToConnect[e.v]);
			int u = takeLast(compToConnect[e.u]);
			ans.push_back({v, u, 1});
		}
	}
	return {true, ans};
}

void solveSingleTest() {
	int n;
	cin >> n;
	vector<vertex> a(n);
	for (int i = 0; i < n; i++) {
		cin >> a[i].white >> a[i].black;
		a[i].id = i;
	}
	answer ans = solve(a);
	if (ans.answerExists) {
		cout << "Yes\n";
		for (auto &e : ans.ans) {
			cout << (e.v + 1) << ' ' << (e.u + 1) << ' ' << (e.color == 0 ? "W" : "B") << '\n';
		}
	} else {
		cout << "No\n";
	}
}

int main() {
	ios::sync_with_stdio(false); cin.tie(NULL);
	int t;
	cin >> t;
	for (int ct = 0; ct < t; ct++) {
		solveSingleTest();
	}
}
