import java.io.PrintWriter

class Vertex(val white: Int, val black: Int, val id: Int) {
    var componentId = -1
}

class Edge(val v: Vertex, val u: Vertex, val color: Char)

fun solve(a: Array<Vertex>): List<Edge>? {
    val n = a.size
    if (n > 1 && a.any { it.white == 0 && it.black == 0 }) {
        return null
    }
    val sumWhite = a.sumOf { it.white.toLong() }
    val sumBlack = a.sumOf { it.black.toLong() }
    val nonZeroWhites = a.count { it.white != 0 }
    if (!(sumWhite % 2 == 0L && sumBlack % 2 == 0L && sumWhite + sumBlack == 2L * (n - 1) && (nonZeroWhites == 0 || sumWhite <= 2 * (nonZeroWhites - 1)))) {
        return null
    }
    val whiteComponents = (2 * n - sumWhite.toInt()) / 2
    val ans = mutableListOf<Edge>()
    val components = mutableListOf<MutableList<Vertex>>()
    a.filter { it.white == 0 }.forEach {
        it.componentId = components.size
        components.add(mutableListOf(it))
    }
    a.filter { it.componentId < 0 && (whiteComponents == 1 || it.black != 0)}.forEach {
        if (components.size < whiteComponents) {
            it.componentId = components.size
            components.add(mutableListOf(it))
        }
    }
    if (components.size != whiteComponents) {
        return null
    }
    val leaves = a.filter { it.componentId < 0 && it.white == 1 }.toMutableList()
    val nonLeaves = a.filter { it.componentId < 0 && it.white > 1 }.toMutableList()
    fun giveLeaves(root: Vertex, count: Int) {
        val compId = root.componentId
        repeat(count) {
            val v = leaves.removeLast()
            v.componentId = compId
            components[compId].add(v)
            ans.add(Edge(root, v, 'W'))
        }
    }
    for (comp in components) {
        val root = comp[0]
        giveLeaves(root, root.white)
    }
    nonLeaves.forEach { u ->
        val last = ans.removeLast()
        ans.add(Edge(last.v, u, 'W'))
        ans.add(Edge(last.u, u, 'W'))
        u.componentId = last.v.componentId
        components[u.componentId].add(u)
        giveLeaves(u, u.white - 2)
    }
    if (whiteComponents > 1) {
        val compToConnect = components.map { list ->
            list.flatMap { u ->
                generateSequence { u }.take(u.black)
            }.toMutableList()
        }
        val leafComps = compToConnect.filter { it.size == 1 }.toMutableList()
        val nonLeafComps = compToConnect.filter { it.size > 1 }.toMutableList()
        while (nonLeafComps.isNotEmpty()) {
            val v = leafComps.removeLast()
            val u = nonLeafComps.last()
            ans.add(Edge(v.last(), u.removeLast(), 'B'))
            if (u.size == 1) {
                nonLeafComps.removeLast()
                leafComps.add(u)
            }
        }
        ans.add(Edge(leafComps.first().first(), leafComps.last().first(), 'B'))
    }
    return ans
}

fun main() {
    val t = readInt()
    repeat(t) {
        val n = readInt()
        val a = Array(n) {
            val (w, b) = readInts()
            Vertex(w, b, it)
        }
        val answer = solve(a)
        if (answer == null) {
            println("No")
        } else {
            println("Yes")
            for (x in answer) {
                println("${x.v.id + 1} ${x.u.id + 1} ${x.color}")
            }
        }
    }
}

private fun readInts() = readWords().map { it.toInt() }
private fun readLongs() = readWords().map { it.toLong() }
private fun readWords() = readLn().split(" ")
private fun readInt() = readLn().toInt()
private fun readLong() = readLn().toLong()
private fun readLn() = readLine()!!